.. _intro:

************
Introduction
************

ANDES is a free software package for power system simulation and analysis based on the Python programming language.  Its
main goal is to provide a convenient and efficient tool for researchers to verify new models and implement new
algorithms by using the elegent Python language and the extensive packages.  ANDES supports power flow calculation, time
domain simulation and full eigenvalue analysis for transmission networks.

